@@ -280,7 +280,7 @@ public class AnnotationProcessorCompiler implements JavaCompiler {
         out.println();
 
     }
-    
+    	
 
    private AnnotationProcessorCompiler( Toolchain toolchain, 
                                          CompilerManager plexusCompiler, 
@@ -314,7 +314,7 @@ public class AnnotationProcessorCompiler implements JavaCompiler {
                 javacConf.addClasspathEntry(ii.next());
             }
             else if( "-sourcepath".equals(option) ) {
-                String [] sourceLocations = ii.next().split(":");
+                String [] sourceLocations = ii.next().split(java.util.regex.Pattern.quote(java.io.File.pathSeparator));
                 for( String path : sourceLocations ) {
                     
                     final java.io.File dir = new java.io.File( path );
@@ -339,28 +339,27 @@ public class AnnotationProcessorCompiler implements JavaCompiler {
             else if( "-s".equals(option) ) {
                 javacConf.setGeneratedSourcesDirectory( new java.io.File(ii.next()));
             }
-            else if( option.startsWith("-A") ) {
+            else /*if( option.startsWith("-A") ) */  { // view pull #70
+                // Just pass through any other arguments
                 javacConf.addCompilerCustomArgument(option, "");   
-                
             }
-            final java.util.Properties props = project.getProperties();
-            
-            final String sourceVersion = props.getProperty(PROCESSOR_SOURCE,props.getProperty(COMPILER_SOURCE, DEFAULT_SOURCE_VERSION));
-            final String targetVersion = props.getProperty(PROCESSOR_TARGET,props.getProperty(COMPILER_TARGET, DEFAULT_TARGET_VERSION));
-            
-            javacConf.setSourceVersion(sourceVersion );
-            javacConf.setTargetVersion(targetVersion);
-            javacConf.setWorkingDirectory(project.getBasedir());
-            
-            final java.util.Set<java.io.File> sourceFiles = 
-                    new java.util.HashSet<java.io.File>();
-            for( JavaFileObject src : compilationUnits ) {
-                sourceFiles.add( new java.io.File( src.toUri() ) );
-                
-            }
-                    
-            javacConf.setSourceFiles(sourceFiles);
         }
+        final java.util.Properties props = project.getProperties();
+
+        final String sourceVersion = props.getProperty(PROCESSOR_SOURCE,props.getProperty(COMPILER_SOURCE, DEFAULT_SOURCE_VERSION));
+        final String targetVersion = props.getProperty(PROCESSOR_TARGET,props.getProperty(COMPILER_TARGET, DEFAULT_TARGET_VERSION));
+
+        javacConf.setSourceVersion(sourceVersion );
+        javacConf.setTargetVersion(targetVersion);
+        javacConf.setWorkingDirectory(project.getBasedir());
+
+        final java.util.Set<java.io.File> sourceFiles = 
+                new java.util.HashSet<java.io.File>();
+        for( JavaFileObject src : compilationUnits ) {
+            sourceFiles.add( new java.io.File( src.toUri() ) );
+        }
+
+        javacConf.setSourceFiles(sourceFiles);
         javacConf.setDebug(false);
         javacConf.setFork(true);
         javacConf.setVerbose(false);
